<?php

namespace Modules\Sd\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Sd\Entities\BlInstruction;
use Modules\Sd\Entities\BlInstructionAttachment;
use Modules\Sd\Entities\ReleaseOrder;
use Modules\Sd\Entities\Shipment;
use Modules\Sd\Entities\ShippingAgent;

class BlInstructionController extends Controller
{
    public function getBlInstructionData()
    {
        try {
            $query = 'SELECT * FROM sd_bl_instruction ORDER BY `created_at` DESC';
            $release_orders = DB::select($query);
            $result = array();

            foreach ($release_orders as $release_order) {
                array_push($result, [
                    "customer_order_id" => $release_order->customer_order_id,
                    "factory_po" => $release_order->factory_po,
                    "shipping_agent_id" => $release_order->shipping_agent_id,
                    "shipment_id" => $release_order->shipment_id,
                    "bl_instruction_id" => $release_order->bl_instruction_id,
                ]);
            }
            $responseBody = $this->responseBody(true, "BlInstructionController", "getblInstructionData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "getblInstructionData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function saveBlInstruction(Request $request)
    {
        try {
            $blInstruction = new BlInstruction();
            $blInstruction->customer_order_id = $request->get('customer_order_id');
            $blInstruction->factory_po = $request->get('factory_po');
            $blInstruction->shipping_agent_id = $request->get('shipping_agent_id');
            $blInstruction->shipment_id = $request->get('shipment_id');
            $blInstruction->note = $request->get('note');

            if ($blInstruction->save()) {
                // $this->sendEmail();
                $attachments = BlInstructionAttachment::where([['sd_bl_instruction_attachment_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->bl_instruction_id = $blInstruction->bl_instruction_id;
                    $attachment->update();
                }
                $attachments = BlInstructionAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->bl_instruction_id = $blInstruction->bl_instruction_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "BlInstructionController", "saveSchedule", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "saveSchedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function updateBlInstruction(Request $request, $id)
    {
        try {
            $blInstruction = BlInstruction::find($id);
            $blInstruction->customer_order_id = $request->get('customer_order_id');
            $blInstruction->factory_po = $request->get('factory_po');
            $blInstruction->shipping_agent_id = $request->get('shipping_agent_id');
            $blInstruction->shipment_id = $request->get('shipment_id');
            $blInstruction->note = $request->get('note');
            if ($blInstruction->update()) {
                $attachments = BlInstructionAttachment::where([['bl_instruction_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->bl_instruction_id = $blInstruction->bl_instruction_id;
                    $attachment->update();
                }
                $attachments = BlInstructionAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->bl_instruction_id = $blInstruction->bl_instruction_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "BlInstructionController", "updateReleaseOrder", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "updateReleaseOrder", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteReleaseOrder(Request $request, $id)
    {
        try {
            $blInstruction = BlInstruction::where('bl_instruction_id', '=', $id);
            $rec_data_attachments = BlInstructionAttachment::where('bl_instruction_id', '=', $id)->get();

            if ($blInstruction->delete()) {
                foreach ($rec_data_attachments as $rec_data_attachment) {
                    $rec_data_attachment->delete();
                }
            }

            $responseBody = $this->responseBody(true, "BlInstructionController", "deleteSchedule", "sucess");
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "deleteSchedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getRoData($id)
    {
        try {
            $recordHead = BlInstruction::find($id);

            $responseBody = $this->responseBody(true, "BlInstructionController", "getRoData", $recordHead);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShipmentData()
    {
        try {
            $shipmet = Shipment::all();

            $responseBody = $this->responseBody(true, "BlInstructionController", "getShipmentData", $shipmet);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "getShipmentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShippingAgentData()
    {
        try {
            $shipping_agent = ShippingAgent::all();

            $responseBody = $this->responseBody(true, "BlInstructionController", "getShippingAgentData", $shipping_agent);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "getShippingAgentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getCustomerOrderData($id)
    {
        try {
            $query = 'SELECT
            sd_shipment.customer_order_id,
            sd_shipment.shipment_id,
            pp_customer_orders.factory_po_num
        FROM
            sd_shipment
            LEFT JOIN pp_customer_orders ON sd_shipment.customer_order_id = pp_customer_orders.order_id
        WHERE
            sd_shipment.shipment_id = ' . $id;
            $orders = DB::select($query);
            $result = array();

            foreach ($orders as $order) {
                array_push($result, [
                    "customer_order_id" => $order->customer_order_id,
                    "factory_po_num" => $order->factory_po_num,
                    "shipment_id" => $order->shipment_id
                ]);
            }


            $responseBody = $this->responseBody(true, "BlInstructionController", "getCustomerOrderData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function uploadScheduleAttachment(Request $request)
    {

        $description = $request->get('foo');
        $token = $request->get('attachmnet_token');
        $file = $request->file('file');
        $file_name = $file->getClientOriginalName();
        $filename = url('/') .'/blinstruction/' . uniqid() . '_' . time() . '.' . str_replace(' ', '_', $file_name);
        //$filename = 'https://erp.rbs.lk/order/' . uniqid() . '_' . time() . '.' .str_replace(' ', '_', $file_name);
        $file->move(public_path('blinstruction'), $filename);

        $blInstruction_attachment = new BlInstructionAttachment();
        $blInstruction_attachment->sd_bl_instruction_attachment_id = 0;
        $blInstruction_attachment->description = $description;
        $blInstruction_attachment->file_path = $filename;
        $blInstruction_attachment->token = $token;
        return $blInstruction_attachment->save();
    }

    public function allScheduleAttachment($id)
    {
        try {

            $attachment = DB::select('SELECT * FROM sd_bl_instruction_attachments WHERE  bl_instruction_id = "' . $id . '" OR bl_instruction_id = "0"');
            $responseBody = $this->responseBody(true, "BlInstructionController", "allVesselAttachment", $attachment);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "allVesselAttachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteScheduleAttachment($id)
    {
        try {
            $rec_data = BlInstructionAttachment::where('sd_bl_instruction_attachment_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $schedule = $data;
                $data->delete();
            }
            $schedule = true;
            $responseBody = $this->responseBody(true, "BlInstructionController", "delete schedule attachment", $schedule);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "BlInstructionController", "delete schedule attachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
