<?php

namespace Modules\Sd\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Sd\Entities\LoadingPlan;
use Modules\Sd\Entities\LoadingPlanAttachment;
use Modules\Sd\Entities\Shipment;
use Modules\Sd\Entities\ShippingAgent;

class LoadingPlanController extends Controller
{
    public function getAllLpData()
    {
        try {
            $query = 'SELECT * FROM sd_loading_plan ORDER BY `created_at` DESC';
            $lp_data = DB::select($query);
            $result = array();

            foreach ($lp_data as $data) {
                array_push($result, [
                    "customer_order_id" => $data->customer_order_id,
                    "factory_po" => $data->factory_po,
                    "shipment_id" => $data->shipment_id,
                    "loading_plan_id" => $data->loading_plan_id,
                ]);
            }
            $responseBody = $this->responseBody(true, "LoadingPlanController", "getAllLpData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "getAllLpData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function saveData(Request $request)
    {
        try {
            $pl_data = new LoadingPlan();
            $pl_data->customer_order_id = $request->get('customer_order_id');
            $pl_data->factory_po = $request->get('factory_po');
            $pl_data->shipment_id = $request->get('shipment_id');
            $pl_data->note = $request->get('note');

            if ($pl_data->save()) {
                // $this->sendEmail();
                $attachments = LoadingPlanAttachment::where([['loading_plan_attachment_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->loading_plan_id = $pl_data->loading_plan_id;
                    $attachment->update();
                }
                $attachments = LoadingPlanAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->loading_plan_id = $pl_data->loading_plan_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "LoadingPlanController", "saveData", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "saveData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function update(Request $request, $id)
    {
        try {
            $lp_data = LoadingPlan::find($id);
            $lp_data->customer_order_id = $request->get('customer_order_id');
            $lp_data->factory_po = $request->get('factory_po');
            $lp_data->shipment_id = $request->get('shipment_id');
            $lp_data->note = $request->get('note');
            if ($lp_data->update()) {
                $attachments = LoadingPlanAttachment::where([['loading_plan_attachment_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->loading_plan_id = $lp_data->loading_plan_id;
                    $attachment->update();
                }
                $attachments = LoadingPlanAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->loading_plan_id = $lp_data->loading_plan_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "PreshipmentDocumentController", "update", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "PreshipmentDocumentController", "update", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function delete(Request $request, $id)
    {
        try {
            $preshipment_doc = LoadingPlan::where('loading_plan_id', '=', $id);
            $rec_data_attachments = LoadingPlanAttachment::where('loading_plan_id', '=', $id)->get();

            if ($preshipment_doc->delete()) {
                foreach ($rec_data_attachments as $rec_data_attachment) {
                    $rec_data_attachment->delete();
                }
            }

            $responseBody = $this->responseBody(true, "LoadingPlanController", "delete", "success");
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "delete", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getAllLoadingPlanData($id)
    {
        try {
            $recordHead = LoadingPlan::find($id);

            $responseBody = $this->responseBody(true, "LoadingPlanController", "getAllLoadingPlanData", $recordHead);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShipmentData()
    {
        try {
            $shipmet = Shipment::all();

            $responseBody = $this->responseBody(true, "LoadingPlanController", "getShipmentData", $shipmet);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "getShipmentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShippingAgentData()
    {
        try {
            $shipping_agent = ShippingAgent::all();

            $responseBody = $this->responseBody(true, "LoadingPlanController", "getShippingAgentData", $shipping_agent);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "getShippingAgentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getCustomerOrderData($id)
    {
        try {
            $query = 'SELECT
            sd_shipment.customer_order_id,
            sd_shipment.shipment_id,
            pp_customer_orders.factory_po_num
        FROM
            sd_shipment
            LEFT JOIN pp_customer_orders ON sd_shipment.customer_order_id = pp_customer_orders.order_id
        WHERE
            sd_shipment.shipment_id = ' . $id;
            $orders = DB::select($query);
            $result = array();

            foreach ($orders as $order) {
                array_push($result, [
                    "customer_order_id" => $order->customer_order_id,
                    "factory_po_num" => $order->factory_po_num,
                    "shipment_id" => $order->shipment_id
                ]);
            }


            $responseBody = $this->responseBody(true, "LoadingPlanController", "getCustomerOrderData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function uploadScheduleAttachment(Request $request)
    {

        $description = $request->get('foo');
        $token = $request->get('attachmnet_token');
        $file = $request->file('file');
        $file_name = $file->getClientOriginalName();
        $filename = url('/') .'/loading_plan/' . uniqid() . '_' . time() . '.' . str_replace(' ', '_', $file_name);
        //$filename = 'https://erp.rbs.lk/order/' . uniqid() . '_' . time() . '.' .str_replace(' ', '_', $file_name);
        $file->move(public_path('loading_plan'), $filename);

        $lp_data = new LoadingPlanAttachment();
        $lp_data->loading_plan_id = 0;
        $lp_data->description = $description;
        $lp_data->file_path = $filename;
        $lp_data->token = $token;
        return $lp_data->save();
    }

    public function allScheduleAttachment($id)
    {
        try {

            $attachment = DB::select('SELECT * FROM sd_loading_plan_attachment WHERE  loading_plan_id = "' . $id . '" OR loading_plan_id = "0"');
            $responseBody = $this->responseBody(true, "LoadingPlanController", "allAttachment", $attachment);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "allAttachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteScheduleAttachment($id)
    {
        try {
            $rec_data = LoadingPlanAttachment::where('loading_plan_attachment_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $schedule = $data;
                $data->delete();
            }
            $schedule = true;
            $responseBody = $this->responseBody(true, "LoadingPlanController", "delete attachment", $schedule);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "LoadingPlanController", "delete attachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
