<?php

namespace Modules\Sd\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Sd\Entities\Shipment;
use Modules\Sd\Entities\ShippingAgent;
use Modules\Sd\Entities\ReleaseOrderAttachment;
use Modules\Sd\Entities\ReleaseOrder;


class ReleaseOrderController extends Controller
{
    public function getReleaseOrderData()
    {
        try {
            $query = 'SELECT * FROM sd_release_order ORDER BY `created_at` DESC';
            $release_orders = DB::select($query);
            $result = array();

            foreach ($release_orders as $release_order) {
                array_push($result, [
                    "customer_order_id" => $release_order->customer_order_id,
                    "factory_po" => $release_order->factory_po,
                    "shipping_agent_id" => $release_order->shipping_agent_id,
                    "shipment_id" => $release_order->shipment_id,
                    "release_order_id" => $release_order->release_order_id,
                ]);
            }
            $responseBody = $this->responseBody(true, "ReleaseOrderController", "getScheduleData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "getScheduleData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function saveReleaseOrder(Request $request)
    {
        try {
            $releaseOrder = new ReleaseOrder();
            $releaseOrder->customer_order_id = $request->get('customer_order_id');
            $releaseOrder->factory_po = $request->get('factory_po');
            $releaseOrder->shipping_agent_id = $request->get('shipping_agent_id');
            $releaseOrder->shipment_id = $request->get('shipment_id');
            $releaseOrder->note = $request->get('note');

            if ($releaseOrder->save()) {
                // $this->sendEmail();
                $attachments = ReleaseOrderAttachment::where([['sd_release_order_attachment_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->release_order_id = $releaseOrder->release_order_id;
                    $attachment->update();
                }
                $attachments = ReleaseOrderAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->release_order_id = $releaseOrder->release_order_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "saveSchedule", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "saveSchedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function updateReleaseOrder(Request $request, $id)
    {
        try {
            $releaseOrder = ReleaseOrder::find($id);
            $releaseOrder->customer_order_id = $request->get('customer_order_id');
            $releaseOrder->factory_po = $request->get('factory_po');
            $releaseOrder->shipping_agent_id = $request->get('shipping_agent_id');
            $releaseOrder->shipment_id = $request->get('shipment_id');
            $releaseOrder->note = $request->get('note');
            if ($releaseOrder->update()) {
                $attachments = ReleaseOrderAttachment::where([['release_order_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->release_order_id = $releaseOrder->release_order_id;
                    $attachment->update();
                }
                $attachments = ReleaseOrderAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->release_order_id = $releaseOrder->release_order_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "updateReleaseOrder", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "updateReleaseOrder", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteReleaseOrder(Request $request, $id)
    {
        try {
            $vesselSchedule = ReleaseOrder::where('release_order_id', '=', $id);
            $rec_data_attachments = ReleaseOrderAttachment::where('release_order_id', '=', $id)->get();

            if ($vesselSchedule->delete()) {
                foreach ($rec_data_attachments as $rec_data_attachment) {
                    $rec_data_attachment->delete();
                }
            }

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "deleteSchedule", "sucess");
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "deleteSchedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getRoData($id)
    {
        try {
            $recordHead = ReleaseOrder::find($id);

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "getRoData", $recordHead);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShipmentData()
    {
        try {
            $shipmet = Shipment::all();

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "getShipmentData", $shipmet);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "getShipmentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getShippingAgentData()
    {
        try {
            $shipping_agent = ShippingAgent::all();

            $responseBody = $this->responseBody(true, "ReleaseOrderController", "getShippingAgentData", $shipping_agent);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "getShippingAgentData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getCustomerOrderData($id)
    {
        try {
            $query = 'SELECT
            sd_shipment.customer_order_id,
            sd_shipment.shipment_id,
            pp_customer_orders.factory_po_num
        FROM
            sd_shipment
            LEFT JOIN pp_customer_orders ON sd_shipment.customer_order_id = pp_customer_orders.order_id
        WHERE
            sd_shipment.shipment_id =' . $id;
            $orders = DB::select($query);
            $result = array();

            foreach ($orders as $order) {
                array_push($result, [
                    "customer_order_id" => $order->customer_order_id,
                    "factory_po_num" => $order->factory_po_num,
                    "shipment_id" => $order->shipment_id,
                ]);
            }


            $responseBody = $this->responseBody(true, "ReleaseOrderController", "getCustomerOrderData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "ReleaseOrderController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function uploadScheduleAttachment(Request $request)
    {

        $description = $request->get('foo');
        $token = $request->get('attachmnet_token');
        $file = $request->file('file');
        $file_name = $file->getClientOriginalName();
        $filename = url('/') .'/release_order_attachment/' . uniqid() . '_' . time() . '.' . str_replace(' ', '_', $file_name);
        //$filename = 'https://erp.rbs.lk/order/' . uniqid() . '_' . time() . '.' .str_replace(' ', '_', $file_name);
        $file->move(public_path('release_order_attachment'), $filename);

        $release_attachment = new ReleaseOrderAttachment();
        $release_attachment->sd_release_order_attachment_id = 0;
        $release_attachment->description = $description;
        $release_attachment->file_path = $filename;
        $release_attachment->token = $token;
        return $release_attachment->save();
    }

    public function allScheduleAttachment($id)
    {
        try {

            $attachment = DB::select('SELECT * FROM sd_release_order_attachments WHERE  release_order_id = "' . $id . '" OR release_order_id = "0"');
            $responseBody = $this->responseBody(true, "releaseOrderController", "allVesselAttachment", $attachment);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "releaseOrderController", "allVesselAttachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteScheduleAttachment($id)
    {
        try {
            $rec_data = ReleaseOrderAttachment::where('sd_release_order_attachment_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $schedule = $data;
                $data->delete();
            }
            $schedule = true;
            $responseBody = $this->responseBody(true, "releaseOrderController", "delete schedule attachment", $schedule);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "releaseOrderController", "delete schedule attachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }

}
