$(document).ready(function () {
    var tableAttachment = $('#tblScheduleAttachment').DataTable({
        responsive: false,
        "scrollX": true,
        "pageLength": 100,
        "order": [],
        "columns": [
            { "data": "rft_no" },
            { "data": "factory_po_num" },
            { "data": "eta" },
            { "data": "customer_po" },
            // { "data": "designation" },
            { "data": "cargo_ready_date" },
            { "data": "suggest_vessel" },
            { "data": "tentative_arrival_date" },
            { "data": "shipping_rate" },
            { "data": "seen" },
            { "data": "status" },
            { "data": "edit", className: "edit", orderable: false },
            { "data": "view", className: "view", orderable: false },
            { "data": "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 80, targets: 1 },
            { width: 80, targets: 2 },
            { width: 80, targets: 3 },
            { width: 30, target: 8, },
            { width: 30, target: 9, },
            { width: 30, target: 10, },
        ],
    });

    allVesselSchedule();
    checkURLPara();
});

function checkURLPara() {
    var pathname = window.location.pathname; //
    const path = pathname.split("/");
    let lastElement = path.pop();

    if (lastElement != 'vesselScheduleList') {

        return $('#tblScheduleAttachment').DataTable().search(lastElement).draw();
    }
}

function allVesselSchedule() {
    $.ajax({
        type: "GET",
        url: "/sd/vesselSchedule/allSchedule",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                var result = response.data.result;
                var data = [];
                for (var i = 0; i < result.length; i++) {
                    var vessel_schedule_id = response.data.result[i]["vessel_schedule_id"];
                    var seen = response.data.result[i]["seen"];
                    var status = response.data.result[i]["status"];

                    if (seen == 0) {
                        var seenIcon = '<span class="badge badge-danger"><i class="fa fa-times" aria-hidden="true"></i></span>'
                    } else {
                        var seenIcon = '<span class="badge badge-success"><i class="fa fa-check" aria-hidden="true"></i></span>'
                    }
                    switch (status) {
                        case 0:
                            StatusIcon = '<span class="badge badge-primary">New</span>';
                            break;
                        case 1:
                            StatusIcon = '<span class="badge badge-success">Approved</span>';
                            break;
                        case 2:
                            StatusIcon = '<span class="badge badge-info">Revise</span>';
                            break;
                        case 3:
                            StatusIcon = '<span class="badge badge-danger">Reject</span>';
                    }


                    data.push({
                        "vessel_schedule_id": result[i].vessel_schedule_id,
                        "factory_po_num": result[i].factory_order_no,
                        "rft_no": result[i].external_id,
                        "eta": result[i].eta,
                        "customer_po": result[i].customer_po,
                        "designation": result[i].designation,
                        "cargo_ready_date": result[i].cargo_ready_date,
                        "suggest_vessel": result[i].suggest_vessel,
                        "tentative_arrival_date": result[i].tentative_arrival_date,
                        "shipping_rate": result[i].shipping_rate,
                        "seen": seenIcon,
                        "status": StatusIcon,
                        "edit": '<button class="btn btn-primary" onclick="edit(' + vessel_schedule_id + ');"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        "view": '<button class="btn btn-success" onclick="view(' + vessel_schedule_id + ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        "delete": '<button class="btn btn-danger" onclick="_delete(' + vessel_schedule_id + ')"><i class="fa fa-trash" aria-hidden="true"></i></button>'
                    });
                }
                var table = $('#tblScheduleAttachment').DataTable();
                table.clear();
                table.rows.add(data).draw();
            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);

        },

    });
}

function view(id) {
    location.href = "/sd/vesselSchedule?id=" + id + "&action=view";
}

function edit(id) {
    location.href = "/sd/vesselSchedule?id=" + id + "&action=edit";
}


function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/sd/VesselScheduleController/delete/" + id,
            success: function (response) {
                console.log(response);
                allVesselSchedule();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

/**
 * showSuccessMessage
 * This function is used to show success message.
 * @param message This is the paramter to require message content
 */
function showSuccessMessage(message) {
    toastr.success(message);
}

/**
 * showWarningMessage
 * This function is used to show warning message.
 * @param message This is the paramter to require message content
 */
function showWarningMessage(message) {
    toastr.warning(message);
}

/**
 * showErrorMessage
 * This function is used to show error message.
 * @param message This is the paramter to require message content
 */
function showErrorMessage() {
    toastr.error("Something went wrong");
}
